# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class NodesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def export_long_burst(self, long_burst_id, node_id, **kwargs):  # noqa: E501
        """Gets a long burst export for a given node  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_long_burst(long_burst_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int long_burst_id: (required)
        :param int node_id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_long_burst_with_http_info(long_burst_id, node_id, **kwargs)  # noqa: E501
        else:
            (data) = self.export_long_burst_with_http_info(long_burst_id, node_id, **kwargs)  # noqa: E501
            return data

    def export_long_burst_with_http_info(self, long_burst_id, node_id, **kwargs):  # noqa: E501
        """Gets a long burst export for a given node  # noqa: E501

        Required Permissions: Location Admin  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_long_burst_with_http_info(long_burst_id, node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int long_burst_id: (required)
        :param int node_id: (required)
        :return: str
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['long_burst_id', 'node_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_long_burst" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'long_burst_id' is set
        if ('long_burst_id' not in params or
                params['long_burst_id'] is None):
            raise ValueError("Missing the required parameter `long_burst_id` when calling `export_long_burst`")  # noqa: E501
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `export_long_burst`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'long_burst_id' in params:
            path_params['longBurstId'] = params['long_burst_id']  # noqa: E501
        if 'node_id' in params:
            path_params['nodeId'] = params['node_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Nodes/{nodeId}/longBurst/{longBurstId}/export', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='str',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def export_nodes(self, **kwargs):  # noqa: E501
        """Requests Node export.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_nodes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `BaseStationId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `BaseStationName` | String | `eq, neq, like, in` | | `BaseStationReceiverSerialNumber` | String | `eq, neq, like, in` | | `BaseStationSerialNumber` | String | `eq, neq, like, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FirmwareVersion` | String | `eq, neq, like, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Nickname` | String | `eq, neq, like, in` | | `NodeTypeCode` | NodeTypeCodes | `eq, neq, in` | | `RepeaterId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `RepeaterName` | String | `eq, neq, like, in` | | `RepeaterSerialNumber` | String | `eq, neq, like, in` | | `SerialNumber` | String | `eq, neq, like, in` |
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `BaseStationName` | String | | `CorporationName` | String | | `Created` | DateTime | | `FirmwareVersion` | String | | `LocationName` | String | | `Nickname` | String | | `NodeTypeCode` | NodeTypeCodes | | `SerialNumber` | String | | `Updated` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `CorporationName`, `LocationName`, `Nickname`, `SerialNumber`.
        :return: PagedResultsModelNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.export_nodes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.export_nodes_with_http_info(**kwargs)  # noqa: E501
            return data

    def export_nodes_with_http_info(self, **kwargs):  # noqa: E501
        """Requests Node export.  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.export_nodes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] group_ids:
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `BaseStationId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `BaseStationName` | String | `eq, neq, like, in` | | `BaseStationReceiverSerialNumber` | String | `eq, neq, like, in` | | `BaseStationSerialNumber` | String | `eq, neq, like, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FirmwareVersion` | String | `eq, neq, like, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Nickname` | String | `eq, neq, like, in` | | `NodeTypeCode` | NodeTypeCodes | `eq, neq, in` | | `RepeaterId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `RepeaterName` | String | `eq, neq, like, in` | | `RepeaterSerialNumber` | String | `eq, neq, like, in` | | `SerialNumber` | String | `eq, neq, like, in` |
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `BaseStationName` | String | | `CorporationName` | String | | `Created` | DateTime | | `FirmwareVersion` | String | | `LocationName` | String | | `Nickname` | String | | `NodeTypeCode` | NodeTypeCodes | | `SerialNumber` | String | | `Updated` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `CorporationName`, `LocationName`, `Nickname`, `SerialNumber`.
        :return: PagedResultsModelNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_ids', 'filter', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method export_nodes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Nodes/export', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelNodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_node(self, node_id, **kwargs):  # noqa: E501
        """Gets the requested node  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node(node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int node_id: The ID of the node (required)
        :param bool include_state: Query parameter used to specify if the returned NodeResponse             should include certain properties
        :return: NodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_node_with_http_info(node_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_node_with_http_info(node_id, **kwargs)  # noqa: E501
            return data

    def get_node_with_http_info(self, node_id, **kwargs):  # noqa: E501
        """Gets the requested node  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_node_with_http_info(node_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int node_id: The ID of the node (required)
        :param bool include_state: Query parameter used to specify if the returned NodeResponse             should include certain properties
        :return: NodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['node_id', 'include_state']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_node" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'node_id' is set
        if ('node_id' not in params or
                params['node_id'] is None):
            raise ValueError("Missing the required parameter `node_id` when calling `get_node`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'node_id' in params:
            path_params['nodeId'] = params['node_id']  # noqa: E501

        query_params = []
        if 'include_state' in params:
            query_params.append(('includeState', params['include_state']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Nodes/{nodeId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='NodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_nodes(self, **kwargs):  # noqa: E501
        """Gets a paginated list of the nodes to which a user has access  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nodes(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool include_state: If set to true node state information will be included in the response
        :param list[str] group_ids: If specified, only nodes assigned to monitoring points under these groupIds will be retrieved
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `BaseStationId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `BaseStationName` | String | `eq, neq, like, in` | | `BaseStationReceiverSerialNumber` | String | `eq, neq, like, in` | | `BaseStationSerialNumber` | String | `eq, neq, like, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FirmwareVersion` | String | `eq, neq, like, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Nickname` | String | `eq, neq, like, in` | | `NodeTypeCode` | NodeTypeCodes | `eq, neq, in` | | `RepeaterId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `RepeaterName` | String | `eq, neq, like, in` | | `RepeaterSerialNumber` | String | `eq, neq, like, in` | | `SerialNumber` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `BaseStationName` | String | | `CorporationName` | String | | `Created` | DateTime | | `FirmwareVersion` | String | | `LocationName` | String | | `Nickname` | String | | `NodeTypeCode` | NodeTypeCodes | | `SerialNumber` | String | | `Updated` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `CorporationName`, `LocationName`, `Nickname`, `SerialNumber`.
        :return: PagedResultsModelNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_nodes_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_nodes_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_nodes_with_http_info(self, **kwargs):  # noqa: E501
        """Gets a paginated list of the nodes to which a user has access  # noqa: E501

        Required Permissions: Location User  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_nodes_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param bool include_state: If set to true node state information will be included in the response
        :param list[str] group_ids: If specified, only nodes assigned to monitoring points under these groupIds will be retrieved
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Active` | Boolean | `eq, neq` | | `BaseStationId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `BaseStationName` | String | `eq, neq, like, in` | | `BaseStationReceiverSerialNumber` | String | `eq, neq, like, in` | | `BaseStationSerialNumber` | String | `eq, neq, like, in` | | `CorporationAbbreviation` | String | `eq, neq, like, in` | | `CorporationId` | Guid | `eq, neq, in` | | `CorporationName` | String | `eq, neq, like, in` | | `FirmwareVersion` | String | `eq, neq, like, in` | | `LocationAbbreviation` | String | `eq, neq, like, in` | | `LocationId` | Guid | `eq, neq, in` | | `LocationName` | String | `eq, neq, like, in` | | `Nickname` | String | `eq, neq, like, in` | | `NodeTypeCode` | NodeTypeCodes | `eq, neq, in` | | `RepeaterId` | Int64 | `eq, neq, in, lt, gt, leq, geq` | | `RepeaterName` | String | `eq, neq, like, in` | | `RepeaterSerialNumber` | String | `eq, neq, like, in` | | `SerialNumber` | String | `eq, neq, like, in` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Active` | Boolean | | `BaseStationName` | String | | `CorporationName` | String | | `Created` | DateTime | | `FirmwareVersion` | String | | `LocationName` | String | | `Nickname` | String | | `NodeTypeCode` | NodeTypeCodes | | `SerialNumber` | String | | `Updated` | DateTime |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `CorporationName`, `LocationName`, `Nickname`, `SerialNumber`.
        :return: PagedResultsModelNodeResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['include_state', 'group_ids', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_nodes" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include_state' in params:
            query_params.append(('includeState', params['include_state']))  # noqa: E501
        if 'group_ids' in params:
            query_params.append(('groupIds', params['group_ids']))  # noqa: E501
            collection_formats['groupIds'] = 'multi'  # noqa: E501
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Nodes', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelNodeResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MonitoringPointOverviewResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'monitoring_point_type': 'MonitoringPointTypeCodes',
        'is_paused': 'bool',
        'is_snoozed': 'bool',
        'running_speed_multiplier': 'float',
        'node': 'MonitoringPointOverviewNodeChild',
        'hierarchy': 'list[OverviewHierarchyChild]',
        'node_settings': 'NodeSettingOverview',
        'bearing_assignment': 'BearingChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'monitoring_point_type': 'MonitoringPointType',
        'is_paused': 'IsPaused',
        'is_snoozed': 'IsSnoozed',
        'running_speed_multiplier': 'RunningSpeedMultiplier',
        'node': 'Node',
        'hierarchy': 'Hierarchy',
        'node_settings': 'NodeSettings',
        'bearing_assignment': 'BearingAssignment'
    }

    def __init__(self, id=None, name=None, monitoring_point_type=None, is_paused=None, is_snoozed=None, running_speed_multiplier=None, node=None, hierarchy=None, node_settings=None, bearing_assignment=None):  # noqa: E501
        """MonitoringPointOverviewResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._monitoring_point_type = None
        self._is_paused = None
        self._is_snoozed = None
        self._running_speed_multiplier = None
        self._node = None
        self._hierarchy = None
        self._node_settings = None
        self._bearing_assignment = None
        self.discriminator = None
        self.id = id
        self.name = name
        if monitoring_point_type is not None:
            self.monitoring_point_type = monitoring_point_type
        self.is_paused = is_paused
        self.is_snoozed = is_snoozed
        if running_speed_multiplier is not None:
            self.running_speed_multiplier = running_speed_multiplier
        if node is not None:
            self.node = node
        if hierarchy is not None:
            self.hierarchy = hierarchy
        if node_settings is not None:
            self.node_settings = node_settings
        if bearing_assignment is not None:
            self.bearing_assignment = bearing_assignment

    @property
    def id(self):
        """Gets the id of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The id of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MonitoringPointOverviewResponse.


        :param id: The id of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The name of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MonitoringPointOverviewResponse.


        :param name: The name of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def monitoring_point_type(self):
        """Gets the monitoring_point_type of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The monitoring_point_type of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: MonitoringPointTypeCodes
        """
        return self._monitoring_point_type

    @monitoring_point_type.setter
    def monitoring_point_type(self, monitoring_point_type):
        """Sets the monitoring_point_type of this MonitoringPointOverviewResponse.


        :param monitoring_point_type: The monitoring_point_type of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: MonitoringPointTypeCodes
        """

        self._monitoring_point_type = monitoring_point_type

    @property
    def is_paused(self):
        """Gets the is_paused of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The is_paused of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_paused

    @is_paused.setter
    def is_paused(self, is_paused):
        """Sets the is_paused of this MonitoringPointOverviewResponse.


        :param is_paused: The is_paused of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: bool
        """
        if is_paused is None:
            raise ValueError("Invalid value for `is_paused`, must not be `None`")  # noqa: E501

        self._is_paused = is_paused

    @property
    def is_snoozed(self):
        """Gets the is_snoozed of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The is_snoozed of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_snoozed

    @is_snoozed.setter
    def is_snoozed(self, is_snoozed):
        """Sets the is_snoozed of this MonitoringPointOverviewResponse.


        :param is_snoozed: The is_snoozed of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: bool
        """
        if is_snoozed is None:
            raise ValueError("Invalid value for `is_snoozed`, must not be `None`")  # noqa: E501

        self._is_snoozed = is_snoozed

    @property
    def running_speed_multiplier(self):
        """Gets the running_speed_multiplier of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The running_speed_multiplier of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: float
        """
        return self._running_speed_multiplier

    @running_speed_multiplier.setter
    def running_speed_multiplier(self, running_speed_multiplier):
        """Sets the running_speed_multiplier of this MonitoringPointOverviewResponse.


        :param running_speed_multiplier: The running_speed_multiplier of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: float
        """

        self._running_speed_multiplier = running_speed_multiplier

    @property
    def node(self):
        """Gets the node of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The node of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: MonitoringPointOverviewNodeChild
        """
        return self._node

    @node.setter
    def node(self, node):
        """Sets the node of this MonitoringPointOverviewResponse.


        :param node: The node of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: MonitoringPointOverviewNodeChild
        """

        self._node = node

    @property
    def hierarchy(self):
        """Gets the hierarchy of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The hierarchy of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: list[OverviewHierarchyChild]
        """
        return self._hierarchy

    @hierarchy.setter
    def hierarchy(self, hierarchy):
        """Sets the hierarchy of this MonitoringPointOverviewResponse.


        :param hierarchy: The hierarchy of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: list[OverviewHierarchyChild]
        """

        self._hierarchy = hierarchy

    @property
    def node_settings(self):
        """Gets the node_settings of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The node_settings of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: NodeSettingOverview
        """
        return self._node_settings

    @node_settings.setter
    def node_settings(self, node_settings):
        """Sets the node_settings of this MonitoringPointOverviewResponse.


        :param node_settings: The node_settings of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: NodeSettingOverview
        """

        self._node_settings = node_settings

    @property
    def bearing_assignment(self):
        """Gets the bearing_assignment of this MonitoringPointOverviewResponse.  # noqa: E501


        :return: The bearing_assignment of this MonitoringPointOverviewResponse.  # noqa: E501
        :rtype: BearingChild
        """
        return self._bearing_assignment

    @bearing_assignment.setter
    def bearing_assignment(self, bearing_assignment):
        """Sets the bearing_assignment of this MonitoringPointOverviewResponse.


        :param bearing_assignment: The bearing_assignment of this MonitoringPointOverviewResponse.  # noqa: E501
        :type: BearingChild
        """

        self._bearing_assignment = bearing_assignment

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MonitoringPointOverviewResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MonitoringPointOverviewResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class MarkerResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'marker_type': 'MarkerType',
        'value': 'float',
        'order': 'int'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'marker_type': 'MarkerType',
        'value': 'Value',
        'order': 'Order'
    }

    def __init__(self, id=None, name=None, marker_type=None, value=None, order=None):  # noqa: E501
        """MarkerResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._marker_type = None
        self._value = None
        self._order = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.marker_type = marker_type
        self.value = value
        self.order = order

    @property
    def id(self):
        """Gets the id of this MarkerResponse.  # noqa: E501


        :return: The id of this MarkerResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this MarkerResponse.


        :param id: The id of this MarkerResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this MarkerResponse.  # noqa: E501


        :return: The name of this MarkerResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this MarkerResponse.


        :param name: The name of this MarkerResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def marker_type(self):
        """Gets the marker_type of this MarkerResponse.  # noqa: E501


        :return: The marker_type of this MarkerResponse.  # noqa: E501
        :rtype: MarkerType
        """
        return self._marker_type

    @marker_type.setter
    def marker_type(self, marker_type):
        """Sets the marker_type of this MarkerResponse.


        :param marker_type: The marker_type of this MarkerResponse.  # noqa: E501
        :type: MarkerType
        """
        if marker_type is None:
            raise ValueError("Invalid value for `marker_type`, must not be `None`")  # noqa: E501

        self._marker_type = marker_type

    @property
    def value(self):
        """Gets the value of this MarkerResponse.  # noqa: E501


        :return: The value of this MarkerResponse.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this MarkerResponse.


        :param value: The value of this MarkerResponse.  # noqa: E501
        :type: float
        """
        if value is None:
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def order(self):
        """Gets the order of this MarkerResponse.  # noqa: E501


        :return: The order of this MarkerResponse.  # noqa: E501
        :rtype: int
        """
        return self._order

    @order.setter
    def order(self, order):
        """Sets the order of this MarkerResponse.


        :param order: The order of this MarkerResponse.  # noqa: E501
        :type: int
        """
        if order is None:
            raise ValueError("Invalid value for `order`, must not be `None`")  # noqa: E501

        self._order = order

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(MarkerResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MarkerResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class ReportsApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def request_base_station_report(self, **kwargs):  # noqa: E501
        """This will download a base station and repeater hardware report for the locations provided in the details model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_base_station_report(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] ids: A list of Locations Guids whose hardware should appear in the report
        :param str file_name: The Name of the File
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.request_base_station_report_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.request_base_station_report_with_http_info(**kwargs)  # noqa: E501
            return data

    def request_base_station_report_with_http_info(self, **kwargs):  # noqa: E501
        """This will download a base station and repeater hardware report for the locations provided in the details model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_base_station_report_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param list[str] ids: A list of Locations Guids whose hardware should appear in the report
        :param str file_name: The Name of the File
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['ids', 'file_name']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method request_base_station_report" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'ids' in params:
            query_params.append(('Ids', params['ids']))  # noqa: E501
            collection_formats['Ids'] = 'multi'  # noqa: E501
        if 'file_name' in params:
            query_params.append(('FileName', params['file_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Reports/hardware/basestation', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def request_heatmap_report(self, group_id, **kwargs):  # noqa: E501
        """Enqueues a job to run and later email a heatmap report for the group provided using the options provided  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_heatmap_report(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: Id of the group to run the report on (required)
        :param HeatmapReportRequest body: Contains the options for the report
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.request_heatmap_report_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.request_heatmap_report_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def request_heatmap_report_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Enqueues a job to run and later email a heatmap report for the group provided using the options provided  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_heatmap_report_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: Id of the group to run the report on (required)
        :param HeatmapReportRequest body: Contains the options for the report
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method request_heatmap_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `request_heatmap_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Reports/heatmap/group/{groupId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def request_low_battery_report(self, location_id, **kwargs):  # noqa: E501
        """This will download a low battery report for the location provided in the details model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_low_battery_report(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: Id of the location whose nodes will appear in the report (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.request_low_battery_report_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.request_low_battery_report_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def request_low_battery_report_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """This will download a low battery report for the location provided in the details model  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_low_battery_report_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: Id of the location whose nodes will appear in the report (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method request_low_battery_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `request_low_battery_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'location_id' in params:
            query_params.append(('LocationId', params['location_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Reports/hardware/lowBattery', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def request_statistics_report(self, group_id, **kwargs):  # noqa: E501
        """Emails a statistics report for the group provided using the options provided  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_statistics_report(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: Id of the group to run the report on (required)
        :param StatisticsReportRequest body: Contains the options for the report
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.request_statistics_report_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.request_statistics_report_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def request_statistics_report_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Emails a statistics report for the group provided using the options provided  # noqa: E501

        Required Permissions: System Admin / Sentry  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.request_statistics_report_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: Id of the group to run the report on (required)
        :param StatisticsReportRequest body: Contains the options for the report
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method request_statistics_report" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `request_statistics_report`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Reports/statistics/group/{groupId}', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IdentityProviderResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'username_identifiers': 'list[str]',
        'corporation_child': 'PrimaryCorporationChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'username_identifiers': 'UsernameIdentifiers',
        'corporation_child': 'CorporationChild'
    }

    def __init__(self, id=None, name=None, username_identifiers=None, corporation_child=None):  # noqa: E501
        """IdentityProviderResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._username_identifiers = None
        self._corporation_child = None
        self.discriminator = None
        self.id = id
        if name is not None:
            self.name = name
        if username_identifiers is not None:
            self.username_identifiers = username_identifiers
        if corporation_child is not None:
            self.corporation_child = corporation_child

    @property
    def id(self):
        """Gets the id of this IdentityProviderResponse.  # noqa: E501

        ID  # noqa: E501

        :return: The id of this IdentityProviderResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IdentityProviderResponse.

        ID  # noqa: E501

        :param id: The id of this IdentityProviderResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IdentityProviderResponse.  # noqa: E501

        Name  # noqa: E501

        :return: The name of this IdentityProviderResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IdentityProviderResponse.

        Name  # noqa: E501

        :param name: The name of this IdentityProviderResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username_identifiers(self):
        """Gets the username_identifiers of this IdentityProviderResponse.  # noqa: E501

        Username Identifier  # noqa: E501

        :return: The username_identifiers of this IdentityProviderResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._username_identifiers

    @username_identifiers.setter
    def username_identifiers(self, username_identifiers):
        """Sets the username_identifiers of this IdentityProviderResponse.

        Username Identifier  # noqa: E501

        :param username_identifiers: The username_identifiers of this IdentityProviderResponse.  # noqa: E501
        :type: list[str]
        """

        self._username_identifiers = username_identifiers

    @property
    def corporation_child(self):
        """Gets the corporation_child of this IdentityProviderResponse.  # noqa: E501


        :return: The corporation_child of this IdentityProviderResponse.  # noqa: E501
        :rtype: PrimaryCorporationChild
        """
        return self._corporation_child

    @corporation_child.setter
    def corporation_child(self, corporation_child):
        """Sets the corporation_child of this IdentityProviderResponse.


        :param corporation_child: The corporation_child of this IdentityProviderResponse.  # noqa: E501
        :type: PrimaryCorporationChild
        """

        self._corporation_child = corporation_child

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IdentityProviderResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IdentityProviderResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class IndicatorFilterResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'is_global': 'bool',
        'indicator_types': 'list[MetricTypeCodes]',
        'sort_order': 'int',
        'tags': 'list[TagChild]',
        'location': 'LocationChild',
        'system': 'SystemChild'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'is_global': 'IsGlobal',
        'indicator_types': 'IndicatorTypes',
        'sort_order': 'SortOrder',
        'tags': 'Tags',
        'location': 'Location',
        'system': 'System'
    }

    def __init__(self, id=None, name=None, is_global=None, indicator_types=None, sort_order=None, tags=None, location=None, system=None):  # noqa: E501
        """IndicatorFilterResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._is_global = None
        self._indicator_types = None
        self._sort_order = None
        self._tags = None
        self._location = None
        self._system = None
        self.discriminator = None
        self.id = id
        self.name = name
        self.is_global = is_global
        if indicator_types is not None:
            self.indicator_types = indicator_types
        if sort_order is not None:
            self.sort_order = sort_order
        if tags is not None:
            self.tags = tags
        if location is not None:
            self.location = location
        if system is not None:
            self.system = system

    @property
    def id(self):
        """Gets the id of this IndicatorFilterResponse.  # noqa: E501


        :return: The id of this IndicatorFilterResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this IndicatorFilterResponse.


        :param id: The id of this IndicatorFilterResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this IndicatorFilterResponse.  # noqa: E501


        :return: The name of this IndicatorFilterResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this IndicatorFilterResponse.


        :param name: The name of this IndicatorFilterResponse.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def is_global(self):
        """Gets the is_global of this IndicatorFilterResponse.  # noqa: E501


        :return: The is_global of this IndicatorFilterResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_global

    @is_global.setter
    def is_global(self, is_global):
        """Sets the is_global of this IndicatorFilterResponse.


        :param is_global: The is_global of this IndicatorFilterResponse.  # noqa: E501
        :type: bool
        """
        if is_global is None:
            raise ValueError("Invalid value for `is_global`, must not be `None`")  # noqa: E501

        self._is_global = is_global

    @property
    def indicator_types(self):
        """Gets the indicator_types of this IndicatorFilterResponse.  # noqa: E501


        :return: The indicator_types of this IndicatorFilterResponse.  # noqa: E501
        :rtype: list[MetricTypeCodes]
        """
        return self._indicator_types

    @indicator_types.setter
    def indicator_types(self, indicator_types):
        """Sets the indicator_types of this IndicatorFilterResponse.


        :param indicator_types: The indicator_types of this IndicatorFilterResponse.  # noqa: E501
        :type: list[MetricTypeCodes]
        """

        self._indicator_types = indicator_types

    @property
    def sort_order(self):
        """Gets the sort_order of this IndicatorFilterResponse.  # noqa: E501


        :return: The sort_order of this IndicatorFilterResponse.  # noqa: E501
        :rtype: int
        """
        return self._sort_order

    @sort_order.setter
    def sort_order(self, sort_order):
        """Sets the sort_order of this IndicatorFilterResponse.


        :param sort_order: The sort_order of this IndicatorFilterResponse.  # noqa: E501
        :type: int
        """

        self._sort_order = sort_order

    @property
    def tags(self):
        """Gets the tags of this IndicatorFilterResponse.  # noqa: E501


        :return: The tags of this IndicatorFilterResponse.  # noqa: E501
        :rtype: list[TagChild]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this IndicatorFilterResponse.


        :param tags: The tags of this IndicatorFilterResponse.  # noqa: E501
        :type: list[TagChild]
        """

        self._tags = tags

    @property
    def location(self):
        """Gets the location of this IndicatorFilterResponse.  # noqa: E501


        :return: The location of this IndicatorFilterResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this IndicatorFilterResponse.


        :param location: The location of this IndicatorFilterResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    @property
    def system(self):
        """Gets the system of this IndicatorFilterResponse.  # noqa: E501


        :return: The system of this IndicatorFilterResponse.  # noqa: E501
        :rtype: SystemChild
        """
        return self._system

    @system.setter
    def system(self, system):
        """Sets the system of this IndicatorFilterResponse.


        :param system: The system of this IndicatorFilterResponse.  # noqa: E501
        :type: SystemChild
        """

        self._system = system

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(IndicatorFilterResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, IndicatorFilterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
